Versions
========

0.0.1
========

_Release date: 30.05.20_

- Implement unittests
- Demonstrate usage in 'Quick start' section
- Remove python3.6 from applicable versions
- Fix CI always passing
- Implement auth credentials unittests
- Support async HTTP sessions
- Implement async HTTP responses
- Support custom URLs
- Implement auth types
- Introduce initial project template